package com.yonge.cooleshow.portal.controller.open;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.cooleshow.mall.common.api.CommonResult;
import com.yonge.cooleshow.mall.common.courier.domain.CourierInfo;
import com.yonge.cooleshow.mall.common.courier.service.CourierService;
import com.yonge.cooleshow.portal.dto.ShareProductVo;
import com.yonge.cooleshow.portal.dto.ShareProfitParam;
import com.yonge.cooleshow.portal.service.OmsOrderCourierService;
import com.yonge.cooleshow.portal.service.OmsPortalOrderService;
import com.yonge.cooleshow.portal.service.PmsPortalProductService;
import com.yonge.toolset.base.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/open")
@Api(tags = "开放权限接口-分享")
public class OpenShareController extends BaseController {
    private final static Logger log = LoggerFactory.getLogger(OpenShareController.class);

    @Autowired
    private SysUserFeignService sysUserFeignService;

    @Autowired
    private PmsPortalProductService portalProductService;

    @Autowired
    private OmsOrderCourierService orderCourierService;

    @Autowired
    private CourierService courierService;

    @ApiOperation(value = "老师商品分享分润")
    @PostMapping(value="/productProfit")
    @ResponseBody
    public CommonResult<ShareProductVo> shareProductProfit(@RequestBody ShareProfitParam param) {
        SysUser sysUser = sysUserFeignService.queryUserById(param.getUserId());
        if (sysUser == null  || sysUser.getId() == null) {
            return CommonResult.failed("用户信息获取失败");
        }
        HttpResponseResult<String> client = sysUserFeignService.client();
        if (client.getStatus()) {
            if (!StringUtil.isEmpty(client.getData()) && "teacher".equals(client.getData())) {
                return CommonResult.success(portalProductService.shareProductProfit(sysUser, param.getBizId()));
            }
        } else {
            return CommonResult.success(portalProductService.shareProductProfit(sysUser, param.getBizId()));
        }
        return CommonResult.failed("分享功能暂未开放");
    }



    @ApiOperation(value = "快递信息回调")
    @PostMapping(value="/courierCallback", consumes = MediaType.APPLICATION_FORM_URLENCODED_VALUE)
    @ResponseBody
    public Object courierCallback( String param) {
        log.info("快递信息回调：{}",param);

        JSONObject jsonObject = JSON.parseObject(param);
        String data = jsonObject.getString("lastResult");
        CourierInfo courierInfos = courierService.getCourierInfos(data);

        // 保存快递信息
        orderCourierService.updateCourierInfo(courierInfos);
        Map<String,Object> result = new HashMap<>();
        result.put("result",true);
        result.put("returnCode","200");
        result.put("message","成功");

        return result;
    }


}
